<?php
/*********************************************************************************
** The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 *
********************************************************************************/

//This array contains all the versions to which are all we are providing migration
//For each and every release we have to add the previous release version in this array

$versions = Array(
			"50"=>"5.0",
			"501"=>"5.0.1",
			"502"=>"5.0.2",
			"503rc2"=>"5.0.3 RC2",
			"503"=>"5.0.3",
			"504rc"=>"5.0.4 RC",
			"504"=>"5.0.4",
			"510rc"=>"5.1.0 RC",
			"510"=>"5.1.0",
			'520rc'=>'5.2.0 RC',
                        '520'=>'5.2.0',
		 );

$current_version = '521';

?>
